#
# spec file for package python3-colorama
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-colorama
Version:        0.3.3
Release:        4.2
Summary:        Cross-platform colored terminal text
License:        BSD-3-Clause
Group:          Development/Languages/Python
Url:            https://github.com/tartley/colorama
Source:         http://pypi.python.org/packages/source/c/colorama/colorama-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Makes ANSI escape character sequences, for producing colored terminal text and
cursor positioning, work under MS Windows.

ANSI escape character sequences have long been used to produce colored terminal
text and cursor positioning on Unix and Macs. Colorama makes this work on
Windows, too. It also provides some shortcuts to help generate ANSI sequences,
and works fine in conjunction with any other ANSI sequence generation library,
such as Termcolor.

This has the upshot of providing a simple cross-platform API for printing
colored terminal text from Python, and has the happy side-effect that existing
applications or libraries which use ANSI sequences to produce colored output on
Linux or Macs can now also work on Windows, simply by calling colorama.init().

%prep
%setup -q -n colorama-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc CHANGELOG.rst LICENSE.txt README.rst demos
%{python3_sitelib}/*

%changelog
* Sat Jan 10 2015 arun@gmx.de
- specfile:
  * update copyright year
  * README.txt-> README.rst
- update to version 0.3.3:
  * Fix Google Code issue #13 - support changing the console title
    with OSC escape sequence
  * Fix Google Code issue #16 - Add support for Windows xterm
    emulators
  * Fix Google Code issue #30 - implement 033[nK (clear line)
  * Fix Google Code issue #49 - no need to adjust for scroll when new
    position is already relative (CSI n ABCD)
  * Fix Google Code issue #55 - erase_data fails on Python 3.x
  * Fix Google Code issue #46 - win32.COORD definition missing
  * Implement 033[0J and 033[1J (clear screen options)
  * Fix default ANSI parameters
  * Fix position after 033[2J (clear screen)
  * Add command shortcuts: colorama.Cursor, colorama.ansi.set_title,
    colorama.ansi.clear_line, colorama.ansi.clear_screen
  * Fix issue #22 - Importing fails for python3 on Windows
  * Thanks to John Szakmeister for adding support for light colors
  * Thanks to Charles Merriam for adding documentation to demos
- changes from version 0.3.2:
  * Thanks to Marc Schlaich (schlamar) for a setup.py fix for
    Python2.5
  * Thanks to Jurko for fix on 64-bit Windows CPython2.5 w/o ctypes
    (issue #56)
  * Thanks to Remi Rampin for: * better github integration, incl
    rendered README and Travis config. * fixed forward slashes in
    README
  * Thanks to Florian Bruhin for fix when stdout or stderr are None
  * Thanks to Simeon Visser for: * closing a file handle using 'with'
  * updating classifiers to include Python 3.3 and 3.4
  * Thanks to Thomas Weininger for fix ValueError on Windows (issue
    [#50])
* Tue Sep  2 2014 toddrme2178@gmail.com
- Initial python 3 version
* Tue Sep  2 2014 toddrme2178@gmail.com
- Update to 0.3.1
  * Fixed crash on exit with closed stdout, with thanks to Marc Abramowitz.
  * Now uses setuptools if available, and falls back to distutils if not.
  * setup.py no longer imports anything from colorama source.
- Update to 0.3.0
  * Move repository to Git, https://github.com/tartley/colorama. (My Mercurial
    repo seemed to be corrupted, I couldn't commit nor view patches of old
    commits, even on fresh checkouts.)
  * Fix always-crash on non-Windows platforms, reported by Matt McCormick.
  * Fix issue #47, incompatible with pyreadline.
* Thu Sep 26 2013 dmueller@suse.com
- update to 0.2.7:
  * Fix problem under 64-bit windows due to ctypes HANDLE size.
  * Fix licensing to the source files
* Mon Apr 29 2013 dmueller@suse.com
- update to 0.2.5:
  * various small bugfixes
* Mon Nov 19 2012 saschpe@suse.de
- Initial version
